@@ -9,10 +9,13 @@ from unittest.mock import AsyncMock, MagicMock, patch
 import pytest
 
 from monarchmoney import MonarchMoney
-from monarchmoney.monarchmoney import (
-    LoginFailedException,
-    RequireMFAException,
-    RequestFailedException,
+from monarchmoney.exceptions import (
+    AuthenticationError,
+    MFARequiredError,
+    MonarchMoneyError,
+    RateLimitError,
+    ServerError,
+    ValidationError,
 )
 
 
@@ -28,19 +31,39 @@ class TestLogin:
         session_file = tmp_path / "test_session.pickle"
         mm = MonarchMoney(session_file=str(session_file))
 
-        mock_response = MagicMock()
-        mock_response.status = 200
-        mock_response.json = AsyncMock(return_value=mock_successful_login_response)
-        mock_response.__aenter__ = AsyncMock(return_value=mock_response)
-        mock_response.__aexit__ = AsyncMock(return_value=None)
+        # Create custom async context manager for response
+        class MockResponse:
+            def __init__(self):
+                self.status = 200
 
-        with patch("monarchmoney.monarchmoney.ClientSession") as mock_session_class:
-            mock_session = AsyncMock()
-            mock_session.post = AsyncMock(return_value=mock_response)
-            mock_session.__aenter__ = AsyncMock(return_value=mock_session)
-            mock_session.__aexit__ = AsyncMock(return_value=None)
-            mock_session_class.return_value = mock_session
+            @property
+            def ok(self):
+                return 200 <= self.status < 300
 
+            async def json(self):
+                return mock_successful_login_response
+
+            async def __aenter__(self):
+                return self
+
+            async def __aexit__(self, exc_type, exc_val, exc_tb):
+                return None
+
+        # Create custom async context manager for session
+        class MockSession:
+            def __init__(self):
+                pass
+
+            def post(self, *args, **kwargs):
+                return MockResponse()
+
+            async def __aenter__(self):
+                return self
+
+            async def __aexit__(self, exc_type, exc_val, exc_tb):
+                return None
+
+        with patch("monarchmoney.services.authentication_service.ClientSession", return_value=MockSession()):
             await mm.login(sample_credentials["email"], sample_credentials["password"])
 
             assert mm.token == "mock_auth_token_abcdef123456"
@@ -56,14 +79,22 @@ class TestLogin:
         session_file = tmp_path / "test_session.pickle"
         mm = MonarchMoney(session_file=str(session_file))
 
-        with patch("monarchmoney.monarchmoney.ClientSession") as mock_session_class:
-            mock_session = AsyncMock()
-            mock_session.post.return_value = mock_mfa_required_response
-            mock_session.__aenter__ = AsyncMock(return_value=mock_session)
-            mock_session.__aexit__ = AsyncMock(return_value=None)
-            mock_session_class.return_value = mock_session
+        # Create custom async context manager for session
+        class MockSession:
+            def __init__(self):
+                pass
 
-            with pytest.raises(RequireMFAException, match="Multi-Factor Auth Required"):
+            def post(self, *args, **kwargs):
+                return mock_mfa_required_response
+
+            async def __aenter__(self):
+                return self
+
+            async def __aexit__(self, exc_type, exc_val, exc_tb):
+                return None
+
+        with patch("monarchmoney.services.authentication_service.ClientSession", return_value=MockSession()):
+            with pytest.raises(MFARequiredError, match="Multi-factor authentication required"):
                 await mm.login(
                     sample_credentials["email"], sample_credentials["password"]
                 )
@@ -76,12 +107,12 @@ class TestLogin:
         mm = MonarchMoney(session_file=str(session_file))
 
         with pytest.raises(
-            LoginFailedException, match="Email and password are required"
+            ValidationError, match="Email and password are required"
         ):
             await mm.login("", "")
 
         with pytest.raises(
-            LoginFailedException, match="Email and password are required"
+            ValidationError, match="Email and password are required"
         ):
             await mm.login(None, None)
 
@@ -381,7 +412,7 @@ class TestSessionManagement:
         """Test ensure_valid_session with no token."""
         mm = MonarchMoney()
 
-        with pytest.raises(RequestFailedException, match="No session token available"):
+        with pytest.raises(MonarchMoneyError, match="No session token available"):
             await mm.ensure_valid_session()
 
     def test_enhanced_session_format(self, tmp_path):
@@ -512,7 +543,7 @@ class TestRetryLogic:
             call_count += 1
             raise Exception("HTTP Code 403: Forbidden")
 
-        with pytest.raises(Exception, match="403: Forbidden"):
+        with pytest.raises(AuthenticationError, match="Access forbidden"):
             await retry_with_backoff(auth_failing_function, max_retries=3)
 
         assert call_count == 1  # Should not retry auth errors
@@ -531,7 +562,7 @@ class TestRetryLogic:
             raise Exception("HTTP Code 500: Internal Server Error")
 
         with patch("asyncio.sleep", new_callable=AsyncMock):
-            with pytest.raises(Exception, match="500: Internal Server Error"):
+            with pytest.raises(ServerError, match="Server error 500: Server error occurred"):
                 await retry_with_backoff(always_failing_function, max_retries=2)
 
         assert call_count == 3  # Initial + 2 retries
